==> igniteui-react-core-16.6.3.tgz: package/ES2015/FilterFactory.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "./type";
import { FilterExpression } from "./FilterExpression";
export class FilterFactory extends Base {
    static get a5() {
        if (FilterFactory.a4 == null) {
            FilterFactory.a4 = new FilterFactory();
        }
        return FilterFactory.a4;
    }
    static c(a) {
        let b = FilterFactory.a5;
        return a(b);
    }
    aj(a) {
        return FilterExpression.property(a);
    }
    aa(a) {
        return FilterExpression.literal(a);
    }
    s(a) {
        return FilterExpression.operation(a, 15, null);
    }
    b(a, b) {
        return FilterExpression.operation(a, 7, b);
    }
    ai(a, b) {
        return FilterExpression.operation(a, 8, b);
    }
    af(a) {
        return FilterExpression.operation(a, 9, null);
    }
    a(a, b) {
        return FilterExpression.operation(a, 10, b);
    }
    l(a, b) {
        return FilterExpression.operation(a, 13, b);
    }
    o(a, b) {
        return FilterExpression.operation(a, 1, b);
    }
    q(a, b) {
        return FilterExpression.operation(a, 3, b);
    }
    r(a, b) {
        return FilterExpression.operation(a, 4, b);
    }
    y(a, b) {
        return FilterExpression.operation(a, 5, b);
    }
    z(a, b) {
        return FilterExpression.operation(a, 6, b);
    }
    ac(a, b) {
        return FilterExpression.operation(a, 14, b);
    }
    ae(a, b) {
        return FilterExpression.operation(a, 12, b);
    }
    ag(a, b) {
        return FilterExpression.operation(a, 2, b);
    }
    ay(a, b) {
        return FilterExpression.operation(a, 11, b);
    }
    e(a) {
        return FilterExpression.$function(19, a);
    }
    f(a, b) {
        return FilterExpression.$function(10, a, b);
    }
    g(a, b) {
        return FilterExpression.$function(10, a, FilterExpression.literal(b));
    }
    h(a, b) {
        return FilterExpression.$function(0, a, b);
    }
    i(a, b) {
        return FilterExpression.$function(0, a, FilterExpression.literal(b));
    }
    k(a) {
        return FilterExpression.$function(11, a);
    }
    m(a, b) {
        return FilterExpression.$function(1, a, b);
    }
    n(a, b) {
        return FilterExpression.$function(1, a, FilterExpression.literal(b));
    }
    p(a) {
        return FilterExpression.$function(18, a);
    }
    t(a) {
        return FilterExpression.$function(12, a);
    }
    u(a, b) {
        return FilterExpression.$function(4, a, b);
    }
    v(a, b) {
        return FilterExpression.$function(4, a, FilterExpression.literal(b));
    }
    x(a) {
        return FilterExpression.$function(3, a);
    }
    ab(a) {
        return FilterExpression.$function(13, a);
    }
    ad(a) {
        return FilterExpression.$function(14, a);
    }
    ak(a, b, c) {
        return FilterExpression.$function(5, a, b, c);
    }
    am(a, b, c) {
        return FilterExpression.$function(5, a, FilterExpression.literal(b), c);
    }
    al(a, b, c) {
        return FilterExpression.$function(5, a, b, FilterExpression.literal(c));
    }
    an(a, b, c) {
        return FilterExpression.$function(5, a, FilterExpression.literal(b), FilterExpression.literal(c));
    }
    ao(a) {
        return FilterExpression.$function(17, a);
    }
    ap(a) {
        return FilterExpression.$function(15, a);
    }
    aq(a, b) {
        return FilterExpression.$function(2, a, b);
    }
    ar(a, b) {
        return FilterExpression.$function(2, a, FilterExpression.literal(b));
    }
    as(a, b) {
        return FilterExpression.$function(6, a, b);
    }
    av(a, b) {
        return FilterExpression.$function(6, a, FilterExpression.literal(b));
    }
    at(a, b, c) {
        return FilterExpression.$function(6, a, b, c);
    }
    aw(a, b, c) {
        return FilterExpression.$function(6, a, FilterExpression.literal(b), c);
    }
    au(a, b, c) {
        return FilterExpression.$function(6, a, b, FilterExpression.literal(c));
    }
    ax(a, b, c) {
        return FilterExpression.$function(6, a, FilterExpression.literal(b), FilterExpression.literal(c));
    }
    a0(a) {
        return FilterExpression.$function(7, a);
    }
    a1(a) {
        return FilterExpression.$function(8, a);
    }
    a2(a) {
        return FilterExpression.$function(9, a);
    }
    a3(a) {
        return FilterExpression.$function(16, a);
    }
    j(a) {
        return FilterExpression.$function(20, a);
    }
    az(a) {
        return FilterExpression.$function(21, a);
    }
    ah() {
        return FilterExpression.$function(16);
    }
    w(a, b) {
        return FilterExpression.$function(16, a);
    }
    d(a, b) {
        return FilterExpression.$function(24, a);
    }
}
FilterFactory.$t = markType(FilterFactory, 'FilterFactory');
FilterFactory.a4 = null;

==> igniteui-react-core-16.6.4.tgz: package/ES2015/FilterFactory.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "./type";
import { FilterExpression } from "./FilterExpression";
export class FilterFactory extends Base {
    static get instance() {
        if (FilterFactory.a4 == null) {
            FilterFactory.a4 = new FilterFactory();
        }
        return FilterFactory.a4;
    }
    static build(a) {
        let b = FilterFactory.instance;
        return a(b);
    }
    property(a) {
        return FilterExpression.property(a);
    }
    literal(a) {
        return FilterExpression.literal(a);
    }
    group(a) {
        return FilterExpression.operation(a, 15, null);
    }
    and(a, b) {
        return FilterExpression.operation(a, 7, b);
    }
    or(a, b) {
        return FilterExpression.operation(a, 8, b);
    }
    not(a) {
        return FilterExpression.operation(a, 9, null);
    }
    add(a, b) {
        return FilterExpression.operation(a, 10, b);
    }
    divide(a, b) {
        return FilterExpression.operation(a, 13, b);
    }
    equal(a, b) {
        return FilterExpression.operation(a, 1, b);
    }
    greaterThan(a, b) {
        return FilterExpression.operation(a, 3, b);
    }
    greaterThanOrEqual(a, b) {
        return FilterExpression.operation(a, 4, b);
    }
    lessThan(a, b) {
        return FilterExpression.operation(a, 5, b);
    }
    lessThanOrEqual(a, b) {
        return FilterExpression.operation(a, 6, b);
    }
    modulus(a, b) {
        return FilterExpression.operation(a, 14, b);
    }
    multiply(a, b) {
        return FilterExpression.operation(a, 12, b);
    }
    notEqual(a, b) {
        return FilterExpression.operation(a, 2, b);
    }
    subtract(a, b) {
        return FilterExpression.operation(a, 11, b);
    }
    ceiling(a) {
        return FilterExpression.$function(19, a);
    }
    concat(a, b) {
        return FilterExpression.$function(10, a, b);
    }
    concat1(a, b) {
        return FilterExpression.$function(10, a, FilterExpression.literal(b));
    }
    contains(a, b) {
        return FilterExpression.$function(0, a, b);
    }
    contains1(a, b) {
        return FilterExpression.$function(0, a, FilterExpression.literal(b));
    }
    day(a) {
        return FilterExpression.$function(11, a);
    }
    endsWith(a, b) {
        return FilterExpression.$function(1, a, b);
    }
    endsWith1(a, b) {
        return FilterExpression.$function(1, a, FilterExpression.literal(b));
    }
    floor(a) {
        return FilterExpression.$function(18, a);
    }
    hour(a) {
        return FilterExpression.$function(12, a);
    }
    indexOf(a, b) {
        return FilterExpression.$function(4, a, b);
    }
    indexOf1(a, b) {
        return FilterExpression.$function(4, a, FilterExpression.literal(b));
    }
    length(a) {
        return FilterExpression.$function(3, a);
    }
    minute(a) {
        return FilterExpression.$function(13, a);
    }
    month(a) {
        return FilterExpression.$function(14, a);
    }
    replace(a, b, c) {
        return FilterExpression.$function(5, a, b, c);
    }
    replace2(a, b, c) {
        return FilterExpression.$function(5, a, FilterExpression.literal(b), c);
    }
    replace1(a, b, c) {
        return FilterExpression.$function(5, a, b, FilterExpression.literal(c));
    }
    replace3(a, b, c) {
        return FilterExpression.$function(5, a, FilterExpression.literal(b), FilterExpression.literal(c));
    }
    round(a) {
        return FilterExpression.$function(17, a);
    }
    second(a) {
        return FilterExpression.$function(15, a);
    }
    startsWith(a, b) {
        return FilterExpression.$function(2, a, b);
    }
    startsWith1(a, b) {
        return FilterExpression.$function(2, a, FilterExpression.literal(b));
    }
    substring(a, b) {
        return FilterExpression.$function(6, a, b);
    }
    substring3(a, b) {
        return FilterExpression.$function(6, a, FilterExpression.literal(b));
    }
    substring1(a, b, c) {
        return FilterExpression.$function(6, a, b, c);
    }
    substring4(a, b, c) {
        return FilterExpression.$function(6, a, FilterExpression.literal(b), c);
    }
    substring2(a, b, c) {
        return FilterExpression.$function(6, a, b, FilterExpression.literal(c));
    }
    substring5(a, b, c) {
        return FilterExpression.$function(6, a, FilterExpression.literal(b), FilterExpression.literal(c));
    }
    toLower(a) {
        return FilterExpression.$function(7, a);
    }
    toUpper(a) {
        return FilterExpression.$function(8, a);
    }
    trim(a) {
        return FilterExpression.$function(9, a);
    }
    year(a) {
        return FilterExpression.$function(16, a);
    }
    date(a) {
        return FilterExpression.$function(20, a);
    }
    time(a) {
        return FilterExpression.$function(21, a);
    }
    now() {
        return FilterExpression.$function(16);
    }
    isOf(a, b) {
        return FilterExpression.$function(16, a);
    }
    cast(a, b) {
        return FilterExpression.$function(24, a);
    }
}
FilterFactory.$t = markType(FilterFactory, 'FilterFactory');
FilterFactory.a4 = null;
